@@ -63,13 +63,13 @@ c   f2(s,z) =int(f^2)ds = s^3/3 cos^2
 c
 c 
 c
-      real*8 f1, f2, int1, int2,  rp, clenbetween2h
+      real*8 f1, f2, int1, int2,  rp  !  , clenbetween2h
       real*8 cvh2denp, cvh2den2p, rho, rhop, d, cvh2thick
       real*8 ct2lTA
 
       real*8 nearv/0.5/, nearv2/0.99/, t1, t2
       real*8 maxact
-      integer i
+      integer i, icon, iterate
 
       f1(s) = -s**2/2*cosp + s**3/rp/6.d0 * (1.d0-cosp**2)
 c     *    +  s**4/rp/rp/8.d0*cosp*(1.d0-cosp**2)    ! negligible
@@ -91,6 +91,7 @@ c----------------------------------------------------------------------
       else
          jcut = 0
       endif
+
       if(.not. (UseTbl .and. z .lt. Htop) .and. 
      *    (abs(cosz) .lt. nearv) ) then
 c               max movable thickness
@@ -100,6 +101,8 @@ c               max movable thickness
         endif
       endif
 c     
+      iterate =0   ! flag for later use. 
+
       if(UseTbl .and. z .lt. Htop) then
          leng = ct2lTA(z,  t)
       elseif( abs(cosz) .gt. nearv ) then
@@ -111,25 +114,39 @@ c
             jcut = 1
          endif
          zp = cthick2h(t2)
-
-         leng = clenbetween2h(z+Eradius, zp+Eradius, cosz)
-         if(abs(cosz) .lt. nearv2) then
-c            correction by using  cos at middle of leng
-            cosp = cnewcos(z+Eradius, cosz, leng/2)
-            t2 = t1 + cosp * t
-            if(t2 .le. 0.) then
+c         leng = clenbetween2h(z+Eradius, zp+Eradius, cosz)
+         call clenbetw2h(z+Eradius, zp+Eradius, cosz, leng, icon)
+         if(icon .ne. 0) then
+c            cannot reach to zp. This may happen if z is very large
+            iterate = 1
+         else
+            if(abs(cosz) .lt. nearv2) then
+c              correction by using  cos at middle of leng
+               cosp = cnewcos(z+Eradius, cosz, leng/2)
+               t2 = t1 + cosp * t
+               if(t2 .le. 0.) then
 c                   we shall move by real length rather than by thickness
-                jcut = 1
-                leng = leng/2
-                zp = cnewh(z+Eradius, cosz, leng) - Eradius
-                t2 = cvh2thick(zp)
-                t =( t2 - t1 )/((cosz+cosp)/2)
-            else
-               zp = cthick2h(t2)
-               leng = clenbetween2h(z+Eradius, zp+Eradius, cosz)
-            endif   
+                  jcut = 1
+                  leng = leng/2
+                  zp = cnewh(z+Eradius, cosz, leng) - Eradius
+                  t2 = cvh2thick(zp)
+                  t =( t2 - t1 )/((cosz+cosp)/2)
+               else
+                  zp = cthick2h(t2)
+c                  leng = clenbetween2h(z+Eradius, zp+Eradius, cosz)
+                  call clenbetw2h(z+Eradius, zp+Eradius, cosz,
+     *                           leng, icon)
+                  if(icon .ne. 0) then
+                     iterate = 1
+                  endif
+               endif   
+            endif
          endif
       else         
+         iterate = 1
+      endif
+      
+      if( iterate .ne. 0) then
          rho = cvh2den(z)
          rhop = cvh2denp(z)
 c               at very high altitude,  rhop = 0
@@ -162,8 +179,8 @@ c                  get new s
                s = (t - cvh2denp(zp)*int1 - cvh2den2p(zp)*int2/2)
      *                 /  cvh2den(zp) 
             enddo
-            leng = s
          endif
+         leng = s
       endif
       end
 
