@@ -134,8 +134,8 @@ c     *
      * '       splot "',tracefile(1:klena(tracefile)),'" w  l'
         write(*, *)
      * '   To see charged particles only, use following '
-        write(*, *)  '      splot  "< awk ',qm,' $6 != 0 {print} \ '
-        write(*, *)  '           NF == 0 {print}',qm, ' \ '
+        write(*, *)  '      splot  "< awk ',qm,' $6 != 0 ; \ '
+        write(*, *)  '           NF == 0 ;',qm, ' \ '
         write(*, *)  '         ',tracefile(1:klena(tracefile)),
      *       ' " w l '
 #ifdef sun4
