@@ -54,7 +54,10 @@ c         *******************************************
               record /component/ each(maxNoOfComps)
               real*8 cummInteFlux(maxNoOfComps)
               integer no_of_comps    ! how many diff. compositions
-              integer NoOfSamplings  ! how many times sampled
+              integer NoOfSamplings  ! total number of samplings including ones discarded by cutoff
+              integer NoOfSampComp(maxNoOfComps, 2)  ! 1 is for number of sampling including
+                                                      ! discarded ones due to cutoff. 2 is only for
+                                                      ! employed ones.
 c                        after a sampling of a 1ry, the following 
 c                        is fixed.
               integer label            ! sampled primary label
