@@ -12,6 +12,8 @@ c
 #include  "Zprimary.h"
 #include  "Zprimaryv.h"
 #include  "Zcondc.h"
+#include  "Zobs.h"
+#include  "Zobsp.h"
 
       character*70 msg
       character*16 temp
@@ -79,6 +81,8 @@ c          manipulate data
       call catmosCnst1
       call catmosCnst2
 #endif
+c         init for geomag
+      call crdGeomag(GeomagFile, YearOfGeomag)
 c        init for LPM effect energy sampling.
       s1 = (7.36d0**(1./3.d0)/183.d0)**2
       call csetLPMCnst(s1, log(s1), 1.d-4, X0)
