@@ -54,7 +54,7 @@ c        den2 = cvh2den(h2)
 c        e2 = MovedTrack.p.fm.p(4)
 c
         if( ka .gt. knuc) then
-           the = thnuc * Code2massN(ka)
+           the = thg * TrackBefMove.p.mass
         else
            the = crnth(ka)
         endif
